@@ -116,6 +116,11 @@ def initializeAsteriskConfig():
 	* macros.inc
 	"""
 
+	tapisupport = False
+        for obj in configlets.configlet_tree:
+	        if obj.__class__.__name__ == 'CfgOptSettings':
+		        if obj.tapi:
+			        tapisupport = True
 
 	# Start with empty config files
 	configlets.asterisk_configfiles = []
@@ -153,8 +158,8 @@ def initializeAsteriskConfig():
 
 
 	c = AstConf("zapata.conf")
-	c.append("language=%s" % getSetting('language', 'en'))
 	c.setSection("channels")
+	c.append("language=%s" % getSetting('language', 'en'))
 	c.append("immediate=no")
 	c.append("overlapdial=yes")
 	
@@ -163,71 +168,108 @@ def initializeAsteriskConfig():
 	c.append("language=%s" % getSetting('language', 'en'))
 
 	needModule("pbx_functions")
-	needModule("cdr_sqlite3_custom")
 	c = AstConf("cdr_sqlite3_custom.conf")
 	c.setSection("master")
 	c.append("table => cdr")
 	c.append("columns => clid,src,dst,dcontext,channel,dstchannel,lastapp,lastdata,start,answer,end,duration,billsec,disposition,amaflags,accountcode,uniqueid,userfield,pbx,intrunk,outtrunk,dialout")
 	c.append("values => '${CDR(clid)}','${CDR(src)}','${CDR(dst)}','${CDR(dcontext)}','${CDR(channel)}','${CDR(dstchannel)}','${CDR(lastapp)}','${CDR(lastdata)}','${CDR(start)}','${CDR(answer)}','${CDR(end)}','${CDR(duration)}','${CDR(billsec)}','${CDR(disposition)}','${CDR(amaflags)}','${CDR(accountcode)}','${CDR(uniqueid)}','${CDR(userfield)}','${CDR(pbx)}','${CDR(intrunk)}','${CDR(outtrunk)}','${CDR(dialout)}'")
 
+	needModule("res_indications")
 	c = AstConf("macros.inc")
 	c.append(";")
 	c.append("; Macro to dial a standard local extension")
 	c.append(";")
-	c.append("; format: Macro(stdexten,dest,voicebox 1/0,ext,pbx)")
+	c.append("; format: Macro(stdexten,dest,ext,pbx)")
 	c.append(";")
 	c.setSection("macro-dial-std-exten")
 	c.append(";")
 	c.append("; test for CFIM (Call Forwarding Immediate)")
-	c.append("exten=s,1,Set(fw_ext=${DB(CFIM/${ARG5}/${ARG4})})")
+	c.append("exten=s,1,Set(fw_ext=${DB(CFIM/${ARG4}/${ARG3})})")
 	c.append('exten=s,n,GotoIf($["${fw_ext}" != ""]?fw)')
 	c.append(";")
+	c.append("; test for VMIM (VM Immediate)")
+	c.append("exten=s,n,Set(vmim=${DB(VMIM/${ARG4}/${ARG3})})")
+	c.append('exten=s,n,GotoIf($["${vmim}" != ""]?vmu)')
+	c.append(";")
 	c.append("; test for DND (Do Not Disturb)")
-	c.append("exten=s,n,Set(temp=${DB(DND/${ARG5}/${ARG4})})")
-	c.append('exten=s,n,GotoIf($["${temp}" = "True"]?testvmu)')
+	c.append("exten=s,n,Set(dnd=${DB(DND/${ARG4}/${ARG3})})")
+	c.append('exten=s,n,GotoIf($["${dnd}" != ""]?busy)')
 	c.append(";")
 	c.append("; get dial seconds")
-	c.append("exten=s,n,Set(dsec=${DB(DSEC/${ARG5}/${ARG4})})")
-	c.append('exten=s,n,GotoIf($["${dsec}" = ""]?:dsecEnd)')
+	c.append("exten=s,n,Set(dsec=${DB(DSEC/${ARG4}/${ARG3})})")
+	c.append('exten=s,n,GotoIf($["${dsec}" != ""]?dsecEnd)')
 	c.append("exten=s,n,Set(dsec=45)")
 	c.append("exten=s,n(dsecEnd),NoOp()")
 	c.append(";")
-	c.append("; get dial options")
+	c.append("; get global dial options")
 	c.append("exten=s,n,Set(dopt=${DIAL_OPTIONS})")
-	c.append('exten=s,n,GotoIf($["${dopt}" = ""]?:doptEnd)')
-	c.append("exten=s,n,Set(dopt=r)")
-	c.append("exten=s,n(doptEnd),NoOp()")
+        if tapisupport:
+	        c.append("exten=s,n,Set(dopt=${dopt}M(tapi^${UNIQUEID}|${ARG1}))")
+	c.append(";")
+	c.append("; get early media")
+	c.append("exten=s,n,Set(emedia=${DB(EMEDIA/${ARG4}/${ARG3})})")
+	c.append('exten=s,n,GotoIf($["${emedia}" = ""]?emediaEnd)')
+	c.append("exten=s,n,Set(dopt=${dopt}m(${emedia}))")
+	c.append("exten=s,n,Answer()")
+	c.append("exten=s,n(emediaEnd),NoOp()")
+	c.append(";")
+	c.append("; parallel ringing")
+	c.append("exten=s,n,Set(prng=${DB(PRNG/${ARG4}/${ARG3})})")
 	c.append(";")
 	c.append("; Dial")
-	c.append("exten=s,n(MainDial),Dial(${ARG1},${dsec},Tt${dopt})")
+	c.append("exten=s,n(MainDial),NoOp()")
+        if tapisupport:
+                c.append("exten=s,n,UserEvent(TAPI|TAPIEVENT: LINE_NEWCALL ${ARG1})")
+                c.append("exten=s,n,UserEvent(TAPI|TAPIEVENT: LINE_CALLSTATE LINECALLSTATE_OFFERING)")
+                c.append("exten=s,n,UserEvent(TAPI|TAPIEVENT: SET CALLERID ${CALLERID})")
+                c.append("exten=s,n,UserEvent(TAPI|TAPIEVENT: LINE_CALLINFO LINECALLINFOSTATE_CALLERID)")
+	c.append("exten=s,n,Dial(${ARG1}${prng},${dsec},TtWw${dopt})")
 	c.append(";")
 	c.append("; Dial result was 'timeout'")
-	c.append("exten=s,n,Set(fw_ext=${DB(CFTO/${ARG5}/${ARG4})})")
+	c.append("exten=s,n(dialtimeout),Set(fw_ext=${DB(CFTO/${ARG4}/${ARG3})})")
 	c.append('exten=s,n,GotoIf($["${fw_ext}" != ""]?fw)')
+	c.append('exten=s,n,GotoIf($["{CDR(intrunk)}" = ""]?cftoend)')
+	c.append("exten=s,n,Set(fw_ext=${DB(CFTO-TRUNK/${ARG4}/${ARG3})})")
+	c.append('exten=s,n,GotoIf($["${fw_ext}" != ""]?fw)')
+	c.append("exten=s,n(cftoend),NoOp()")
 	c.append(";")
 	c.append("; no CFTO (Call Forward Timeout), test VM U.")
-	c.append("exten=s,n,Goto(testvmu)")
+	c.append("exten=s,n,Set(vmu=${DB(VMU/${ARG4}/${ARG3})})")
+	c.append('exten=s,n,GotoIf($["${vmu}" != ""]?vmu)')
+	c.append("exten=s,n,Goto(hangup)")
 	c.append(";")
 	c.append("; Dial result was 'busy'")
-	c.append("exten=s,MainDial+101,Set(fw_ext=${DB(CFBS/${ARG5}/${ARG4})})")
+	c.append("exten=s,MainDial+101(busy),Set(fw_ext=${DB(CFBS/${ARG4}/${ARG3})})")
 	c.append('exten=s,n,GotoIf($["${fw_ext}" != ""]?fw)')
+	c.append('exten=s,n,GotoIf($["{CDR(intrunk)}" = ""]?cfbsend)')
+	c.append("exten=s,n,Set(fw_ext=${DB(CFBS-TRUNK/${ARG4}/${ARG3})})")
+	c.append('exten=s,n,GotoIf($["${fw_ext}" != ""]?fw)')
+	c.append("exten=s,n(cfbsend),NoOp()")
 	c.append(";")
 	c.append("; no CFBS (Call Forward Busy), test VM Busy")
-	c.append("exten=s,n,Goto(testvmb)")
+	c.append("exten=s,n,Set(vmbs=${DB(VMBS/${ARG4}/${ARG3})})")
+	c.append('exten=s,n,GotoIf($["${vmbs}" != ""]?vmbs)')
+	c.append("exten=s,n,Answer()")
+	c.append("exten=s,n,Playtones(busy)")
+	c.append("exten=s,n,Busy()")
 	c.append(";")
 	c.append("exten=s,n(fw),Goto(${ARG2},${fw_ext},1)")
 	c.append(";")
-	c.append('exten=s,n(testvmu),GotoIf($["${ARG3}" = "1"]?:hangup)')
-	c.append('exten=s,n,Set(vmopt=u)')
-	c.append("exten=s,n,Macro(voicemail,${vmopt}${ARG4}@${ARG5})")
+	c.append('exten=s,n(vmu),Set(vmopt=u)')
+	c.append("exten=s,n,Macro(voicemail,${vmopt}${ARG3}@${ARG4})")
 	c.append(";")
-	c.append('exten=s,n(testvmb),GotoIf($["${ARG3}" = "1"]?:hangup)')
-	c.append('exten=s,n,Set(vmopt=b)')
-	c.append("exten=s,n,Macro(voicemail,${vmopt}${ARG4}@${ARG5})")
+	c.append('exten=s,n(vmbs),Set(vmopt=b)')
+	c.append("exten=s,n,Macro(voicemail,${vmopt}${ARG3}@${ARG4})")
 	c.append(";")
 	c.append("exten=s,n(hangup),Hangup()")
 	c.append(";")
 	c.append("exten=i,0,Hangup")
+        if tapisupport:
+                c.append("exten=h,1,UserEvent(TAPI|TAPIEVENT: LINE_CALLSTATE LINECALLSTATE_IDLE)")
+
+                c.append("[macro-tapi];")
+                c.append("exten=s,1,UserEvent(TAPI|TAPIEVENT: [~${ARG1}&${ARG2}] LINE_CALLSTATE LINECALLSTATE_CONNECTED)")
+                c.append("exten=s,2,UserEvent(TAPI|TAPIEVENT: [~${ARG1}&!${ARG2}] LINE_CALLSTATE LINECALLSTATE_HANGUP)")
 
 	c.append(";")
 	c.append("; format: Macro(voicemail,<VoiceMail arguments>)")
@@ -363,13 +405,17 @@ def createAsteriskConfig():
 	c.setSection("modules")
 	c.append("autoload=no")
 	for m in c.modules.preload:
-		c.append("preload=%s.so" % m)
-		if not m in available_modules: missing_modules.append(m)
+		if not m in available_modules:
+			missing_modules.append(m)
+		else:
+			c.append("preload=%s.so" % m)
 
 	for sect in ("pbx", "codec", "format", "res", "cdr", "chan", "func", "app"):
 		for m in c.modules[sect]:
-			c.append("load=%s.so" % m)
-			if not m in available_modules: missing_modules.append(m)
+			if not m in available_modules:
+				missing_modules.append(m)
+			else:
+				c.append("load=%s.so" % m)
 
 	# test if all config files are OK to be written or overwritten
 	tmp_conf = []
