@@ -24,12 +24,23 @@ from configlets import *
 class CfgAppDirectory(CfgApp):
 
 	shortName   = _("Directory")
+	newObjectTitle  = _("New Directory")
 	description = _("""This application allows you to dial by name.""")
-	variables   = [VarType("ext", title=_("Extension"), len=6)]
+	
+	def createVariables(self):
+		self.variables   = [ 	VarType("pbx",    title=_("Virtual PBX"), type="choice", options=getChoice("CfgOptPBX")),
+					VarType("ext", title=_("Extension"), len=6)
+					]
+		self.dependencies = [ DepType("pbx", 
+					type="hard",
+					message = _("This is a Dependency")),
+					]
 
 	def createAsteriskConfig(self):
+		needModule("app_directory")
+	
 		c = AstConf("extensions.conf")
-		c.setSection("apps")
+		c.setSection(self.pbx)
 		c.appendExten(self.ext, "Directory(default)")
 		c.appendExten(self.ext, "Hangup")
 
