@@ -24,15 +24,23 @@ from configlets import *
 class CfgAppEcho(CfgApp):
 
 	shortName   = _("Echo test")
+	newObjectTitle  = _("New Echo test extension")
 	description = _("""The echo test immediately plays back what you speek. You can
 			   use this to find out how much echo you have.""")
-	variables   = [VarType("ext", title=_("Extension"), len=6)]
+			   
+	def createVariables(self):
+		self.variables   = [VarType("pbx",    title=_("Virtual PBX"), type="choice", options=getChoice("CfgOptPBX")),
+				VarType("ext", title=_("Extension"), len=6)]
+		self.dependencies = [ DepType("pbx", 
+					type="hard",
+					message = _("This is a Dependency")),
+					]
 
 	def createAsteriskConfig(self):
 		needModule("app_echo")
 
 		c = AstConf("extensions.conf")
-		c.setSection("apps")
+		c.setSection(self.pbx)
 		c.appendExten(self.ext, "Answer")
 		c.appendExten(self.ext, "Wait(1)")
 		c.appendExten(self.ext, "Playback(demo-echotest,skip)")
