@@ -24,21 +24,30 @@ from configlets import *
 class CfgAppVoiceMail(CfgApp):
 
 	shortName   = _("Voicemail dialog")
+	newObjectTitle  = _("New voicemail dialog")
 	description = _("""Extension to enter the voicemail system.""")
-	variables   = [ VarType("ext", title=_("Extension"), len=6),
+	
+	def createVariables(self):
+		self.variables   = [ VarType("pbx",    title=_("Virtual PBX"), type="choice", options=getChoice("CfgOptPBX")),
+			VarType("ext", title=_("Extension"), len=6),
 			VarType("mailbox", title=_("Ask for user mailbox?"), type="bool", optional=True),
-			]
+		]
+
+		self.dependencies = [ DepType("pbx", 
+					type="hard",
+					message = _("This is a Dependency")),
+					]
 
 	def createAsteriskConfig(self):
 		needModule("res_adsi")
 		needModule("app_voicemail")
 
 		c = AstConf("extensions.conf")
-		c.setSection("apps")
+		c.setSection(self.pbx)
 		c.appendExten(self.ext, "Answer")
 		c.appendExten(self.ext, "Wait(1)")
 		if not self.mailbox:
-			c.appendExten(self.ext, "VoiceMailMain(${CALLERIDNUM})")
+			c.appendExten(self.ext, "VoiceMailMain(${CALLERIDNUM}@%s)" % self.pbx)
 		else:
-			c.appendExten(self.ext, "VoiceMailMain")
+			c.appendExten(self.ext, "VoiceMailMain(@%s)" % self.pbx)
 		c.appendExten(self.ext, "Hangup")
