@@ -147,7 +147,7 @@ class CfgIVRAutoatt(CfgIVR):
 			pbx = "phones"
 		s.append("include=%s" % pbx)
 		s.appendExten("s","Wait(%d)" % self.waittime)
-		s.appendExten("s","Set(TIMEOUT(digit)=%d" % self.digittimeout)
+		s.appendExten("s","Set(TIMEOUT(digit)=%d)" % self.digittimeout)
 		if self.moh:
 			s.appendExten("s","Setmusiconhold(%s)" % self.moh)
 			s.appendExten("s","Set(DIAL_OPTIONS=m)")
@@ -171,10 +171,10 @@ class CfgIVRAutoatt(CfgIVR):
 		s.appendExten("i","Goto(%s,%s,1)" % (pbx,self.ext))	
 		s.appendExten("t","ResetCDR(w)")
 		s.appendExten("t","NoCDR")
-		s.appendExten("t","Hungup")
+		s.appendExten("t","Hangup")
 		s.appendExten("T","ResetCDR(w)")
 		s.appendExten("T","NoCDR")
-		s.appendExten("T","Hungup")
+		s.appendExten("T","Hangup")
 	
 
 	def row(self):
