@@ -25,10 +25,13 @@ from configlets import *
 class CfgIVRRaw(CfgIVR):
 
 	shortName = _("Raw IVR")
-	variables = [
-		VarType("name", title=_("Name"), len=15),
-		VarType("txt",  title=_("Contents"), type="text", size=8, cols=40),
-	]
+	newObjectTitle= _("New raw IVR")
+	
+	def createVariables(self):
+		self.variables = [
+			VarType("name", title=_("Name"), len=15),
+			VarType("txt",  title=_("Contents"), type="text", size=8, cols=40),
+		]
 
 	def createAsteriskConfig(self):
 		c = AstConf("extensions.conf")
