@@ -25,8 +25,11 @@ from configlets import *
 class CfgOptPickup(CfgOptSingle):
 
 	shortName = _("Pickup Extension")
+	newObjectTitle= _("Pickup Extension")
 	description = _("Extension to dial to pick-up a call in the same group.")
-	variables = [VarType("ext", title=_("Extension"), len=6)
+	
+	def createVariables(self):
+		self.variables = [VarType("ext", title=_("Extension"), len=6)
 		    ]
 
 	def row(self):
