@@ -24,12 +24,15 @@ from configlets import *
 class CfgOptRawCfg(CfgOpt):
 
 	shortName = _("Raw config file snippet")
-	variables = [
-		VarType("name", title=_("Name"), len=25),
-		VarType("file", title=_("File name"), len=15),
-		VarType("sect", title=_("Section/Context"), len=35),
-		VarType("txt",  title=_("Contents"), type="text", size=8, cols=40),
-	]
+	newObjectTitle= _("New raw config file snippet")
+	
+	def createVariables(self):
+		self.variables = [
+			VarType("name", title=_("Name"), len=25),
+			VarType("file", title=_("File name"), len=15),
+			VarType("sect", title=_("Section/Context"), len=35),
+			VarType("txt",  title=_("Contents"), type="text", size=8, cols=40),
+		]
 
 	def createAsteriskConfig(self):
 		file = self.file
