@@ -71,6 +71,19 @@ class CfgPhoneIax(CfgPhone):
 			VarType("callgroup",
 					title=_("Call group number"),
 					optional=True),
+
+			VarType("QueueLab",
+					title=_("Call Queues"),
+					type="label",
+					hide=True),
+			
+			VarType("queues",
+					title=_("Agent of queues:"),
+					type="mchoice",
+					optional=True,
+					options=getChoice("CfgPhoneQueue"),
+					hide=True),
+	
 	
 			VarType("panelLab",
 					title=_("Operator Panel"),
@@ -87,11 +100,6 @@ class CfgPhoneIax(CfgPhone):
 					title=_("Voicemail settings"),
 					type="label"),
 
-			VarType("usevm",
-					title=_("Use voicemail"),
-					type="bool",
-					optional=True),
-
 			VarType("usemwi",
 					title=_("Signal waiting mail"),
 					type="bool",
@@ -99,9 +107,16 @@ class CfgPhoneIax(CfgPhone):
 
 			VarType("pin",
 					title=_("Voicemail PIN"),
+					type="int",
 					optional=True,
 					len=6),
 
+			VarType("email",
+					title=_("Voicemail email"),
+					optional=True,
+					len=60),
+			
+
 			VarType("notransfer",
 					title=_("Skip asterisk media path?"),
 					type="bool"),
@@ -266,3 +281,4 @@ class CfgPhoneIax(CfgPhone):
 		self.createVoicemailConfig(iax)
 		self.createOutgoingContext()
 		self.createPanelConfig()
+		self.createQueuesConfig()
