@@ -91,17 +91,24 @@ class CfgPhoneMGCP(CfgPhone):
 			VarType("callgroup",
 					title=_("Call group number"),
 					optional=True),
+	
+			VarType("QueueLab",
+					title=_("Call Queues"),
+					type="label",
+					hide=True),
+			
+			VarType("queues",
+					title=_("Agent of queues:"),
+					type="mchoice",
+					optional=True,
+					options=getChoice("CfgPhoneQueue"),
+					hide=True),
 
 			VarType("Voicemail",
 					title=_("Voicemail settings"),
 					type="label",
 					len=6),
 
-			VarType("usevm",
-					title=_("Use voicemail"),
-					type="bool",
-					optional=True),
-
 			VarType("usemwi",
 					title=_("Signal waiting mail"),
 					type="bool",
@@ -112,6 +119,11 @@ class CfgPhoneMGCP(CfgPhone):
 					optional=True,
 					len=6),
 
+			VarType("email",
+					title=_("Voicemail email"),
+					optional=True,
+					len=60),
+			
 			VarType("Outbound",
 					title=_("Calls from the phone"),
 					type="label"),
@@ -269,3 +281,4 @@ class CfgPhoneMGCP(CfgPhone):
 		self.createExtensionConfig()
 		self.createVoicemailConfig(mgcp)
 		self.createOutgoingContext()
+		self.createQueuesConfig()
