@@ -26,7 +26,7 @@ class CfgPhoneQueue(CfgPhone):
 
 	shortName = _("Normal Call Queue")
 	newObjectTitle = _("New Call Queue")
-	technology = "Virtual"
+	technology = "QUEUE"
 	
 	def createVariables(self):
 		self.variables = [
@@ -45,16 +45,31 @@ class CfgPhoneQueue(CfgPhone):
 					len=6),
 
 			VarType("timeout",
-					title=_("Timeout"),
+					title=_("Phone timeout"),
 					optional=True,
 					len=6),
 
+	                VarType("queuetimeout",
+        	            		title=_("Queue Timeout"),
+                                	optional=True,
+                                	len=6),
+
+                	VarType("queuetimeoutext",
+                        		title=_("On queue timeout forward to extension"),
+                        		type="choice",
+                        		optional=True,
+                        		options=getChoice("CfgPhone")),
+
 			VarType("moh",
 					title=_("Music-on-hold class"),
 					type="choice",
 					optional=True,
 					options=getChoice("CfgOptMusic")),
 
+			VarType("ring",
+					title=_("Ring instead of playing Music-on-Hold?"),
+					type="bool"),
+
 			VarType("strategy",
 					title=_("Strategy:"),
 					type="choice",
@@ -225,20 +240,35 @@ class CfgPhoneQueue(CfgPhone):
 			else:
 				mon_line = "MixMonitor(${TIMESTAMP}-${CALLERIDNAME}(${CALLERIDNUM})-${EXTEN}.%s|%s)" % (self.monitorfileformat,options)
 
+		qnames = []
 		if self.ext:
-                        extensions.appendExten(self.ext, "Answer")
-			if self.moh:
-				extensions.appendExten(self.ext, "SetMusicOnHold(%s)" % self.moh)
+		    qnames.append(self.ext)
+		if self.name:
+		    qnames.append(self.name)
+
+		for qname in qnames:
+			opt = "Tth"
 			if mon_line:
-				extensions.appendExten(self.ext, mon_line)
-			extensions.appendExten(self.ext, "Queue(%s|Tth)" % self.name)
+				extensions.appendExten(qname, mon_line)
 
+			if self.ring:
+				opt = opt + "r"
+				
+			if self.moh:
+				extensions.appendExten(qname, "Answer")
+				extensions.appendExten(qname, "SetMusicOnHold(%s)" % self.moh)
 
-		extensions.appendExten(self.name, "Answer")
-		if self.moh:
-			extensions.appendExten(self.name, "SetMusicOnHold(%s)" % self.moh)
-		if mon_line:
-			extensions.appendExten(self.name, mon_line)
-		extensions.appendExten(self.name, "Queue(%s|Tth)" % self.name)
+			if self.queuetimeout and self.queuetimeoutext:
+				opt = opt + "n"
+				extensions.appendExten(qname, "Queue(%s|%s|||%s)" % (self.name, opt, self.queuetimeout))
+				import configlets
+				obj = configlets.configlet_tree.getConfigletByName(self.queuetimeoutext)
+				try:
+					extensions.appendExten(qname, "Goto(%s,%s,1)" %  (obj.pbx, self.queuetimeoutext))
+				except AttributeError:
+					pass
+			else:
+				extensions.appendExten(qname, "Queue(%s|%s)" % (self.name, opt))
+		self.createPanelConfig()
 
 
