@@ -109,11 +109,6 @@ class CfgPhoneSip(CfgPhone):
 					type="label",
 					len=6),
 					
-			VarType("usevm",
-					title=_("Use voicemail"),
-					type="bool",
-					optional=True),
-			
 			VarType("usemwi",
 					title=_("Signal waiting mail"),
 					type="bool",
@@ -121,6 +116,7 @@ class CfgPhoneSip(CfgPhone):
 			
 			VarType("pin",
 					title=_("Voicemail PIN"),
+					type="int",
 					optional=True,
 					len=6),
 			
@@ -301,7 +297,6 @@ class CfgPhoneSip(CfgPhone):
 		sip.append("subscribecontext=%s" % pbx)
 
 		self.createExtensionConfig()
-		self.createHintConfig()
 		self.createVoicemailConfig(sip)
 		self.createOutgoingContext()
 		self.createPanelConfig()
