@@ -78,6 +78,18 @@ class CfgPhoneZap(CfgPhone):
 			VarType("callgroup",
 				title=_("Call group number"),
 				optional=True),
+	
+			VarType("QueueLab",
+					title=_("Call Queues"),
+					type="label",
+					hide=True),
+			
+			VarType("queues",
+					title=_("Agent of queues:"),
+					type="mchoice",
+					optional=True,
+					options=getChoice("CfgPhoneQueue"),
+					hide=True),
 			
 			VarType("panelLab",
 				title=_("Operator Panel"),
@@ -95,11 +107,6 @@ class CfgPhoneZap(CfgPhone):
 				type="label",
 				len=6),
 			
-			VarType("usevm",
-				title=_("Use voicemail"),
-				type="bool",
-				optional=True),
-				
 			VarType("usemwi",
 				title=_("Signal waiting mail"),
 				type="bool",
@@ -107,9 +114,15 @@ class CfgPhoneZap(CfgPhone):
 
 			VarType("pin",
 				title=_("Voicemail PIN"),
+				type="int",
 				optional=True,
 				len=6),
 	
+			VarType("email",
+					title=_("Voicemail email"),
+					optional=True,
+					len=60),
+			
 			VarType("Outbound",
 				title=_("Calls from the phone"),
 				type="label"),
@@ -242,13 +255,20 @@ class CfgPhoneZap(CfgPhone):
 		elif self.calleridname:
 			c.append('callerid="%s"' % self.calleridname)
 		elif self.calleridnum:
-			c.append('callerid=%s' % self.calleridnum)
+			c.append('callerid=<%s>' % self.calleridnum)
+		else:
+			c.append('callerid=<%s>' % self.ext)
 		c.append("context=out-%s" % self.name)
 
 		if self.group:
 			c.appendValue(self, "group")
 		c.append("txgain=0.0")
 		c.append("rxgain=0.0")
+
+		if self.enablecallgroup:
+			c.append('callgroup=%s' % self.callgroup)
+			c.append('pickupgroup=%s' % self.callgroup)
+
 		c.append("channel=%s" % self.channels)
 		c.append("")
 
@@ -258,25 +278,21 @@ class CfgPhoneZap(CfgPhone):
 		c.append("fxo%s=%s" % (self.sigtype, self.channels))
 		c.append("")
 
-		if self.enablecallgroup:
-			c.append('callgroup=%s' % self.callgroup)
-			c.append('pickupgroup=%s' % self.callgroup)
-
 		self.createExtensionConfig()
 		self.createVoicemailConfig(c)
 		self.createOutgoingContext()
 		self.createPanelConfig()
+		self.createQueuesConfig()
 
 	def channelString(self):
 		return "%s/%s" % (self.technology, self.channels)
 
 
 	def createDialEntry(self, extensions, exten, pbx, ext):
-		ret = extensions.appendExten(exten, "Macro(dial-std-exten,%s/%s,out-%s,%d,%s,%s)" % (
+		ret = extensions.appendExten(exten, "Macro(dial-std-exten,%s/%s,out-%s,%s,%s)" % (
 			self.technology,
 			self.channels,
 			self.name,
-			int(self.usevm),
 			pbx,
 			ext)
 		      )
