@@ -29,29 +29,82 @@ class CfgTrunkZap(CfgTrunk):
 	technology = "ZAP"
 	def createVariables(self):
 		self.variables = [
-			VarType("name",       title=_("Name"), len=35),
-			VarType("channels",    title=_("Zaptel channel number"), type="string", len=5),
-			VarType("signalling", title=_("Signalling type"), type="choice",
-								  options=[('fxs_ls','loopstart'),('fxs_ks', 'kewlstart')]),
-			VarType("group",      title=_("Callout group"), type="int", default=1, optional=True),
-	
-			VarType("panelLab",   title=_("Operator Panel"), type="label", hide=True),
-					VarType("panel",      title=_("Show this trunk in the panel"), type="bool", hide=True, optional=True),
-	
-			VarType("Gains",      title=_("Reception and Transmission Gains"), type="label"),
-			VarType("rxgain",     title=_("Reception gain"), hint=_("in dB"), optional=True, default="0.0"),
-			VarType("txgain",     title=_("Transmission gain"), hint=_("in dB"), optional=True, default="0.0"),
-		
-			VarType("Inbound",    title=_("Calls from ZAP trunk"), type="label"),
-			VarType("contextin",      title=_("Go to"), type="radio", default='phone',
-										   options=[('phone',_("Phone")),('ivr',_("IVR"))]),
-			VarType("phone",      title=_("Extension to ring"), type="choice", optional=False,
-										   options=getChoice("CfgPhone")),
-			VarType("ivr",      title=_("IVR to jump to"), type="choice", optional=True,
-										   options=getChoice("CfgIVR")),
-			VarType("clid",       title=_("Change Caller*Id to:"), len=25, optional=True),
-			VarType("dial", hide=True, len=50),
-		]
+			VarType("name",
+				title=_("Name"),
+				len=35),
+
+			VarType("channels",
+				title=_("Zaptel channel number"),
+				type="string",
+				len=5),
+
+			VarType("signalling",
+				title=_("Signalling type"),
+				type="choice",
+				options=[('fxs_ls','loopstart'),('fxs_ks', 'kewlstart')]),
+
+			VarType("group",
+				title=_("Callout group"),
+				type="int",
+				optional=True),
+
+			VarType("panelLab",
+				title=_("Operator Panel"),
+				type="label",
+				hide=True),
+
+			VarType("panel",
+				title=_("Show this trunk in the panel"),
+				type="bool",
+				hide=True,
+				optional=True),
+
+			VarType("Gains",
+				title=_("Reception and Transmission Gains"),
+				type="label"),
+
+			VarType("rxgain",
+				title=_("Reception gain"),
+				hint=_("in dB"),
+				optional=True,
+				default="0.0"),
+
+			VarType("txgain",
+				title=_("Transmission gain"),
+				hint=_("in dB"),
+				optional=True,
+				default="0.0"),
+
+			VarType("Inbound",
+				title=_("Calls from ZAP trunk"),
+				type="label"),
+
+			VarType("clid",
+				title=_("Change Caller*Id to:"),
+				len=25,
+				optional=True),
+
+			VarType("contextin",
+				title=_("Go to"),
+				type="radio",
+				default='phone',
+				options=[('phone',_("Phone")),('ivr',_("IVR")),('pbx',_("Virtual PBX"))]),
+
+			VarType("phone",
+				title=_("Extension to ring"),
+				type="choice",
+				optional=False,
+				options=getChoice("CfgPhone")),
+
+			VarType("ivr",
+				title=_("IVR to jump to"),
+				type="choice",
+				optional=True,
+				options=getChoice("CfgIVR")),
+
+			VarType("dial",
+				hide=True,
+				len=50),]
 
 		self.dependencies = [
 			DepType("phone", 
