@@ -30,31 +30,94 @@ class CfgTrunkZapPBX(CfgTrunk):
 	
 	def createVariables(self):
 		self.variables = [
-			VarType("name",       title=_("Name"), len=35),
-			VarType("channels",    title=_("Zaptel channel number"), type="string", len=5),
-			VarType("signalling", title=_("Signalling type"), type="choice",
-								  options=[('fxs_ls','loopstart'),('fxs_ks', 'kewlstart')]),
-			VarType("group",      title=_("Callout group"), type="int", default=1, optional=True),
+			VarType("name",
+				title=_("Name"),
+				len=35),
+
+			VarType("channels",
+				title=_("Zaptel channel number"),
+				type="string",
+				len=5),
+
+			VarType("signalling",
+				title=_("Signalling type"),
+				type="choice",
+				options=[('fxs_ls','loopstart'),('fxs_ks', 'kewlstart')]),
+
+			VarType("group",
+				title=_("Callout group"),
+				type="int",
+				optional=True),
 	
-			VarType("panelLab",   title=_("Operator Panel"), type="label", hide=True),
-					VarType("panel",      title=_("Show this trunk in the panel"), type="bool", hide=True, optional=True),
+			VarType("panelLab",
+				title=_("Operator Panel"),
+				type="label",
+				hide=True),
+
+			VarType("panel",
+				title=_("Show this trunk in the panel"),
+				type="bool",
+				hide=True,
+				optional=True),
+
+			VarType("Gains",
+				title=_("Reception and Transmission Gains"),
+				type="label"),
+
+			VarType("rxgain",
+				title=_("Reception gain"),
+				hint=_("in dB"),
+				optional=True,
+				default="0.0"),
+
+			VarType("txgain",
+				title=_("Transmission gain"),
+				hint=_("in dB"),
+				optional=True,
+				default="0.0"),
 	
-			VarType("Gains",      title=_("Reception and Transmission Gains"), type="label"),
-			VarType("rxgain",     title=_("Reception gain"), hint=_("in dB"), optional=True, default="0.0"),
-			VarType("txgain",     title=_("Transmission gain"), hint=_("in dB"), optional=True, default="0.0"),
+			VarType("prefix",
+				title=_("Outbound prefix"),
+				default="0",
+				hint=_("Used to call through a PBX"),
+				optional=False ),
 	
-			VarType("prefix",     title=_("Outbound prefix"), default="0", hint=_("Used to call through a PBX"), optional=False ),
-	
-			VarType("Inbound",    title=_("Calls from SIP trunk"), type="label"),
-			VarType("contextin",      title=_("Go to"), type="radio", default='phone',
-										   options=[('phone',_("Phone")),('ivr',_("IVR"))]),
-			VarType("phone",      title=_("Extension to ring"), type="choice", optional=False,
-										   options=getChoice("CfgPhone")),
-			VarType("ivr",      title=_("IVR to jump to"), type="choice", optional=True,
-										   options=getChoice("CfgIVR")),
-			VarType("clid",       title=_("Change Caller*Id to:"), len=25, optional=True),
-			VarType("dial", hide=True, len=50),
-		]
+			VarType("Inbound",
+				title=_("Calls from SIP trunk"),
+				type="label"),
+
+			VarType("clid",
+				title=_("Change Caller*Id to:"),
+				len=25,
+				optional=True),
+
+			VarType("contextin",
+				title=_("Go to"),
+				type="radio",
+				default='phone',
+				options=[('phone',_("Phone")),('ivr',_("IVR")),('pbx',_("Virtual PBX"))]),
+
+			VarType("phone",
+				title=_("Extension to ring"),
+				type="choice",
+				optional=False,
+				options=getChoice("CfgPhone")),
+
+			VarType("ivr",
+				title=_("IVR to jump to"),
+				type="choice",
+				optional=True,
+				options=getChoice("CfgIVR")),
+
+			VarType("pbx",
+				title=_("Allow dial extension from which Virtual PBX"),
+				type="choice",
+				optional=True,
+				options=getChoice("CfgOptPBX")),
+
+			VarType("dial",
+				hide=True,
+				len=50),]
 
 		self.dependencies = [
 			DepType("phone", 
@@ -74,7 +137,7 @@ class CfgTrunkZapPBX(CfgTrunk):
 		CfgTrunk.fixup(self)
 		if not self.rxgain:
 			self.rxgain = "0.0"
-		if not self.txgain: 
+		if not self.txgain:
 			self.txgain = "0.0"
 
 
