@@ -45,7 +45,9 @@ class AsteriskConfigFile:
 	def __init__(self, fn):
 		if fn == 'zaptel.conf':
 			fn = os.path.join("/etc", fn)
-		if fn == 'op_server.cfg' or fn == 'op_buttons.cfg':
+		if fn == 'op_server.cfg' or \
+		   	fn == 'op_buttons.cfg' or\
+			fn == 'op_style.cfg' :
 			fn = os.path.join(panelutils.PANEL_CONF_DIR, fn)
 		elif fn.find('/')==-1:
 			fn = os.path.join(CONF_DIR, fn)
@@ -102,7 +104,7 @@ class AsteriskConfigFile:
 			self.order.append(self.section)
 		self.dirty = True
 
-	def appendExten(self,ext,l,e=None):
+	def appendExten(self,ext,l,e=None, label=None):
 		"""Append an extension line l to the current section. Append
 		an optional error extenion e as well. Increments the priorty
 		if the extension stays the same, resets the prio to 1 if the
@@ -111,7 +113,12 @@ class AsteriskConfigFile:
 		if ext != self.lastext:
 			self.extpriority = 1
 		self.lastext = ext
-		self.append("exten=%s,%d,%s" % (ext, self.extpriority, l))
+
+		if label:
+		    self.append("exten=%s,%d(%s),%s" % (ext, self.extpriority, label, l))
+		else:
+		    self.append("exten=%s,%d,%s" % (ext, self.extpriority, l))
+
 		if e:
 			self.append("exten=%s,%d,%s" % (ext, self.extpriority+101, e))
 			
@@ -871,24 +878,14 @@ class CfgTrunk(Cfg):
 		c = AstConf("extensions.conf")
 		contextin = "in-%s" % self.name
 		c.setSection(contextin)
-		c.appendExten("_X.","Set(CDR(intrunk)=%s)" %  self.name)
-		if self.clid:
-			needModule("func_callerid")
-			c.appendExten("_X.","Set(CALLERID(name)=%s)" %  self.clid)
-		global configlet_tree
-		if self.contextin == 'phone' and self.phone:
-			obj = configlet_tree.getConfigletByName(self.phone)
-			try:
-				pbx = obj.pbx
-				c.appendExten("_X.", "Goto(%s,%s,1)" % (pbx,self.phone))
-			except AttributeError:
-				pass
-		if self.contextin == 'ivr' and self.ivr:
-			c.appendExten("_X.", "Goto(%s,s,1)" % self.ivr)
 		c.appendExten("s","Set(CDR(intrunk)=%s)" %  self.name)
 		if self.clid:
 			needModule("func_callerid")
 			c.appendExten("s","Set(CALLERID(name)=%s)" %  self.clid)
+		if self.clidnumin:
+			needModule("func_callerid")
+			c.appendExten("s","Set(CALLERID(number)=%s)" %  self.clidnumin)
+		global configlet_tree
 		if self.contextin == 'phone' and self.phone:
 			obj = configlet_tree.getConfigletByName(self.phone)
 			try:
@@ -898,6 +895,46 @@ class CfgTrunk(Cfg):
 				pass
 		if self.contextin == 'ivr' and self.ivr:
 			c.appendExten("s", "Goto(%s,s,1)" % self.ivr)
+		if self.contextin == 'pbx' and self.pbx:
+			c.appendExten("s", "Goto(%s,s,1)" % self.pbx)
+
+		c.appendExten("_X","Set(CDR(intrunk)=%s)" %  self.name)
+		if self.clid:
+			needModule("func_callerid")
+			c.appendExten("_X","Set(CALLERID(name)=%s)" %  self.clid)
+		if self.clidnumin:
+			needModule("func_callerid")
+			c.appendExten("_X","Set(CALLERID(number)=%s)" %  self.clidnumin)
+		if self.contextin == 'phone' and self.phone:
+			obj = configlet_tree.getConfigletByName(self.phone)
+			try:
+				pbx = obj.pbx
+				c.appendExten("_X", "Goto(%s,%s,1)" % (pbx,self.phone))
+			except AttributeError:
+				pass
+		if self.contextin == 'ivr' and self.ivr:
+			c.appendExten("_X", "Goto(%s,s,1)" % self.ivr)
+		if self.contextin == 'pbx' and self.pbx:
+			c.appendExten("_X", "Goto(%s,${EXTEN},1)" % self.pbx)
+
+		c.appendExten("_X.","Set(CDR(intrunk)=%s)" %  self.name)
+		if self.clid:
+			needModule("func_callerid")
+			c.appendExten("_X.","Set(CALLERID(name)=%s)" %  self.clid)
+		if self.clidnumin:
+			needModule("func_callerid")
+			c.appendExten("_X.","Set(CALLERID(number)=%s)" %  self.clidnumin)
+		if self.contextin == 'phone' and self.phone:
+			obj = configlet_tree.getConfigletByName(self.phone)
+			try:
+				pbx = obj.pbx
+				c.appendExten("_X.", "Goto(%s,%s,1)" % (pbx,self.phone))
+			except AttributeError:
+				pass
+		if self.contextin == 'ivr' and self.ivr:
+			c.appendExten("_X.", "Goto(%s,s,1)" % self.ivr)
+		if self.contextin == 'pbx' and self.pbx:
+			c.appendExten("_X.", "Goto(%s,${EXTEN},1)" % self.pbx)
 
 		
 class CfgPhone(Cfg):
@@ -939,11 +976,10 @@ class CfgPhone(Cfg):
 					v.hide = False
 
 	def createDialEntry(self, extensions, exten, pbx, ext):
-		ret = extensions.appendExten(exten, "Macro(dial-std-exten,%s/%s,out-%s,%d,%s,%s)" % (
+		ret = extensions.appendExten(exten, "Macro(dial-std-exten,%s/%s,out-%s,%s,%s)" % (
 			self.technology,
 			self.name,
 			self.name,
-			int(self.usevm),
 			ext,
 			pbx
 			))
@@ -957,24 +993,30 @@ class CfgPhone(Cfg):
                 except AttributeError:
                         pbx = "phones"
                 extensions.setSection(pbx)
+		extensions.append("exten=%s,hint,%s/%s" % (self.ext, self.technology, self.name))
 		extensions.appendExten(self.ext,"Set(CDR(pbx)=%s,CDR(userfield)=%s)" % (pbx,self.name))
 		self.createDialEntry(extensions, self.ext, pbx, self.ext)
 		extensions.appendExten(self.name,"Set(CDR(pbx)=%s,CDR(userfield)=%s)" % (pbx,self.name))
 		self.createDialEntry(extensions, self.name, pbx, self.ext)
-
-	def createHintConfig(self):
-		extensions = AstConf("extensions.conf")
-        	try:
-            		pbx = self.pbx
-        	except AttributeError:
-            		pbx = "phones"
-        	extensions.setSection(pbx)
-		extensions.append("exten=%s,hint,%s/%s" % (self.ext, self.technology, self.name))
+		for obj in configlet_tree:
+			if obj.__class__.__name__ == 'CfgAppCallFW':
+				if obj.devstateprefix:
+					extensions.append("exten=%s%s,hint,DS/%s_%s_%s" % (obj.devstateprefix, self.ext, obj.type.lower(), pbx, self.ext))
+					extensions.appendExten("%s%s" % (obj.devstateprefix, self.ext), "Goto(%s,%s,1)" % (pbx, obj.set))
+		for obj in configlet_tree:
+			if obj.__class__.__name__ == 'CfgAppVoicemailSettings':
+				if obj.devstateprefix:
+					extensions.append("exten=%s%s,hint,DS/%s_%s_%s" % (obj.devstateprefix, self.ext, obj.type.lower(), pbx, self.ext))
+					extensions.appendExten("%s%s" % (obj.devstateprefix, self.ext), "Goto(%s,%s,1)" % (pbx, obj.set))
 
 	def createVoicemailConfig(self, conf):
-		if self.ext and self.usevm:
-			needModule("res_adsi")
-			needModule("app_voicemail")
+		vmconfig = False;
+		for obj in configlet_tree:
+			if obj.__class__.__name__ == 'CfgOptVoicemail':
+				if obj.enable:
+				    vmconfig = True;
+				break
+		if vmconfig:
 			if self.usemwi:
 				conf.append("mailbox=%s@%s" % (self.ext,self.pbx))
 
