@@ -33,6 +33,7 @@ PANEL_CONF_DIR	= "/etc/op-panel"
 PANEL_HTML_DIR	= "/usr/share/op-panel/flash"
 PANEL_START_CMD	= "/etc/init.d/op-panel start"
 PANEL_STOP_CMD	= "/etc/init.d/op-panel stop"
+PANEL_RESTART_CMD = "/etc/init.d/op-panel restart"
 
 def isConfigured ():
 	import configlets
@@ -74,6 +75,43 @@ def createDefaultConfig(c):
 	c.append('transfer_timeout="%s"' % _("0,No timeout|300,5 minutes|600,10 minutes|1200,20 minutes|2400,40 minutes|3000,50 minutes"))
 	c.append("enable_restart = 0")
 
+def createDefaultStyle(c):
+	c.setSection("general")
+	c.append("shake_pixels=2")
+	c.append("dimm_noregister_by=20")
+	c.append("dimm_lagged_by=60")
+	c.append("enable_label_background=0")
+	c.append("enable_crypto=0")
+	c.append("enable_animation=1")
+	c.append("use_embed_fonts=1")
+	c.append("ledcolor_ready=0x00A000")
+	c.append("ledcolor_busy=0xA01020")
+	c.append("ledcolor_agent=0xD0d020")
+	c.append("label_font_family=Verdana")
+	c.append("label_font_color=000000")
+	c.append("label_shadow_color=dddddd")
+	c.append("label_shadow=1")
+	c.append("clid_font_color=00dd00")
+	c.append("timer_font_color=4000ff")
+	c.append("clid_font_family=Verdana")
+	c.append("clid_margin_top=0")
+	c.append("clid_margin_left=25")
+	c.append("timer_font_family=Courier")
+	c.append("timer_margin_left=6")
+	c.append("btn_padding=4")
+	c.append("btn_line_width=2")
+	c.append("btn_line_color=0x000000")
+	c.append("btn_fadecolor_1=ccccff")
+	c.append("btn_fadecolor_2=ffffff")
+	c.append("btn_highlight_color=ff0000")
+	c.append("arrow_margin_left=15")
+	c.append("show_security_code=1")
+	c.append("show_clid_info=0")
+	c.append("show_btn_help=3")
+	c.append("show_btn_debug=0")
+	c.append("show_btn_reload=2")
+	c.append("show_status=4")
+
 def createExtButton(obj):
 	p = AstConf("op_buttons.cfg")
 	p.setSection("%s/%s" % (obj.technology, obj.name) )
@@ -122,8 +160,7 @@ def stopPanelDaemon():
 def restartPanelDaemon():
 	s = []
 	s.append(_("Restarting the panel daemon ..."))
-	s.append(stopPanelDaemon())
-	s.append(startPanelDaemon())
+        s.append(commands.getoutput(PANEL_RESTART_CMD))
 	return s
 
 if isConfigured():
